package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.SystemTempMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.ISystemTemp;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.EntryResult;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.google.common.collect.Lists;
import com.google.common.collect.Sets;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/SystemTempService.class */
public class SystemTempService implements ISystemTemp {
    private SystemTempMapper systemTemp = (SystemTempMapper) InstanceUtil.newDaoInstance(SystemTempMapper.class);

    public int searchCount(HttpSession session, String name, String content) throws Exception {
        return this.systemTemp.searchCount(name, content, DataRule.getRuleWhere(session, "t_sys_policies"));
    }

    public List<Map<String, Object>> search(HttpSession session, String name, String content, Integer offset, Integer limit) throws Exception {
        return this.systemTemp.search(name, content, offset, limit, DataRule.getRuleWhere(session, "t_sys_policies"));
    }

    @Transactional
    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        Integer count = this.systemTemp.getCountSysByTmpid(id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("此系统模板已被系统资产引用，请在资产管理中移除引用关系！");
        }
        Map<String, Object> systemp = this.systemTemp.getTemplateById(id);
        String path = ObjectUtil.getString(systemp.get("path"), "");
        if (StringUtils.isNotBlank(path)) {
            File f = new File(Constant.SYSTEM_DIC, path);
            f.delete();
        }
        this.systemTemp.delMidByTmpId(id);
        Integer rcount = Integer.valueOf(this.systemTemp.delete(id, version, DataRule.getRuleWhere(session, "t_sys_policies")));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    @Transactional
    public Integer insert(HttpSession session, String name, Boolean checkFlag, String content, String desct, String family, String poliname, Integer lv, String cve) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        int count = this.systemTemp.getCountByName(name, (Integer) null, (Integer) null).intValue();
        if (count > 0) {
            throw new UEException("模板名称已存在");
        }
        List<String> midIds = new ArrayList<>();
        List<String> contentList = new ArrayList<>(Arrays.asList(content.split(",")));
        try {
            if (checkFlag.booleanValue()) {
                List<String> ids = this.systemTemp.getPoliIds(family, poliname, lv, cve, (String) null, (String) null, (String) null);
                ids.removeAll(contentList);
                for (String d : ids) {
                    midIds.add(ObjectUtil.getString(d, ""));
                }
            } else {
                for (String d2 : contentList) {
                    midIds.add(ObjectUtil.getString(d2, ""));
                }
            }
            Map<String, Object> result = new HashMap<>();
            result.put("name", StringUtils.isBlank(name) ? "新建模板【" + new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()) + "】" : name);
            result.put("desct", desct);
            result.put("uid", uid);
            this.systemTemp.insert(result);
            Integer id = ObjectUtil.getInt(result.get("id"));
            if (midIds != null && midIds.size() > 0) {
                this.systemTemp.addSysMiddle(id, midIds);
                Map<String, Object> tempLv = EntryResult.parseEntry(this.systemTemp.getSysMidByTmpId(id), "lv", "c");
                int high = ObjectUtil.getInt(tempLv.get(ReportService.REPORT_STATE_SUCCESS), 0);
                int medium = ObjectUtil.getInt(tempLv.get(ReportService.REPORT_STATE_FAILED), 0);
                int low = ObjectUtil.getInt(tempLv.get("3"), 0);
                int info = ObjectUtil.getInt(tempLv.get("4"), 0);
                this.systemTemp.update(id, name, Integer.valueOf(high), Integer.valueOf(medium), Integer.valueOf(low), Integer.valueOf(info), desct, 0, DataRule.getRuleWhere(session, "t_sys_policies"), uid);
            }
            return id;
        } catch (Exception e) {
            throw e;
        }
    }

    @Transactional
    public void update(HttpSession session, Integer id, String name, String content, Boolean checkFlag, Integer version, String desct, String family, String poliname, Integer lv, String cve) throws Exception {
        List<String> policies;
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.systemTemp.getCountByName(name, id, uid);
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在");
        }
        List<String> midIds = new ArrayList<>();
        List<String> contentList = new ArrayList<>(Arrays.asList(content.split(",")));
        if (checkFlag.booleanValue()) {
            List<String> ids = this.systemTemp.getPoliIds(family, poliname, lv, cve, (String) null, (String) null, (String) null);
            ids.removeAll(contentList);
            for (String d : ids) {
                if (StringUtils.isNotBlank(d)) {
                    midIds.add(ObjectUtil.getString(d, ""));
                }
            }
        } else {
            for (String d2 : contentList) {
                if (StringUtils.isNotBlank(d2)) {
                    midIds.add(ObjectUtil.getString(d2, ""));
                }
            }
        }
        List<String> oldList = this.systemTemp.getMidPidByTmpid(id);
        if (!midIds.contains(oldList) && (policies = getDifferenceSetByGuava(midIds, oldList)) != null && policies.size() > 0) {
            this.systemTemp.addSysMiddle(id, policies);
            Map<String, Object> tempLv = EntryResult.parseEntry(this.systemTemp.getSysMidByTmpId(id), "lv", "c");
            int high = ObjectUtil.getInt(tempLv.get(ReportService.REPORT_STATE_SUCCESS), 0);
            int medium = ObjectUtil.getInt(tempLv.get(ReportService.REPORT_STATE_FAILED), 0);
            int low = ObjectUtil.getInt(tempLv.get("3"), 0);
            int info = ObjectUtil.getInt(tempLv.get("4"), 0);
            Integer rcount = Integer.valueOf(this.systemTemp.update(id, name, Integer.valueOf(high), Integer.valueOf(medium), Integer.valueOf(low), Integer.valueOf(info), desct, version, DataRule.getRuleWhere(session, "t_sys_policies"), uid));
            if (rcount.intValue() == 0) {
                throw new UEException("数据已被修改或删除，请刷新页面或返回");
            }
        }
    }

    public Map<String, Object> getTemplateById(Integer id) throws Exception {
        return this.systemTemp.getTemplateById(id);
    }

    public List<Map<String, Object>> getPoliciesByFm(String family, String name, Integer lv, String cve, Integer offset, Integer limit) throws Exception {
        Map<String, Object> map = new HashMap<>();
        map.put("family", family);
        map.put("name", name);
        map.put("lv", lv);
        map.put("cve", cve);
        map.put("offset", offset);
        map.put("limit", limit);
        return this.systemTemp.getPoliciesByFm(map);
    }

    public Map<String, Object> getPolilyById(Integer id) throws Exception {
        return this.systemTemp.getPolilyById(id);
    }

    public Map<String, Object> getPolilyByOid(String oid) throws Exception {
        return this.systemTemp.getPolilyByOId(oid);
    }

    public Integer getPoliCountByFm(String family, String name, Integer lv, String cve) throws Exception {
        Map<String, Object> map = new HashMap<>();
        map.put("family", family);
        map.put("name", name);
        map.put("lv", lv);
        map.put("cve", cve);
        return this.systemTemp.getPoliCountByFm(map);
    }

    public List<Map<String, Object>> getIdAndName(HttpSession session) throws Exception {
        return this.systemTemp.getIdAndName(DataRule.getRuleWhere(session, "t_sys_policies"));
    }

    public List<Map<String, Object>> getCheckedPoli(Integer id, Integer offset, Integer limit, String family, String name, Integer lv, String cve, String cnnvd, String cncve, String cnvd) throws Exception {
        return this.systemTemp.getCheckedPoli(id, family, name, lv, cve, cnnvd, cncve, cnvd, offset, limit);
    }

    public List<String> getFamily() throws Exception {
        return this.systemTemp.getFamily();
    }

    private List<String> getDifferenceSetByGuava(List<String> big, List<String> small) {
        return Lists.newArrayList(Sets.difference(Sets.newHashSet(big), Sets.newHashSet(small)));
    }

    @Transactional
    public void delSysPolies(HttpSession session, Integer id, String content, Boolean checkFlag, Integer version) throws Exception {
        List<String> midIds = new ArrayList<>();
        List<String> contentList = new ArrayList<>(Arrays.asList(content.split(",")));
        if (checkFlag.booleanValue()) {
            if (StringUtils.isBlank(content)) {
                this.systemTemp.delMidByTmpId(id);
            } else {
                List<String> ids = this.systemTemp.getMidPidByTmpid(id);
                List<String> idInt = new ArrayList<>();
                for (String conid : contentList) {
                    idInt.add(ObjectUtil.getString(conid, ""));
                }
                midIds.addAll(getDifferenceSetByGuava(ids.size() > idInt.size() ? ids : idInt, ids.size() > idInt.size() ? idInt : ids));
                this.systemTemp.delSysMiddle(id, midIds);
            }
        } else {
            List<String> oldList = this.systemTemp.getMidPidByTmpid(id);
            oldList.removeAll(contentList);
            for (String d : contentList) {
                midIds.add(ObjectUtil.getString(d, ""));
            }
            this.systemTemp.delSysMiddle(id, midIds);
        }
        Map<String, Object> tempLv = EntryResult.parseEntry(this.systemTemp.getSysMidByTmpId(id), "lv", "c");
        int high = ObjectUtil.getInt(tempLv.get(ReportService.REPORT_STATE_SUCCESS), 0);
        int medium = ObjectUtil.getInt(tempLv.get(ReportService.REPORT_STATE_FAILED), 0);
        int low = ObjectUtil.getInt(tempLv.get("3"), 0);
        int info = ObjectUtil.getInt(tempLv.get("4"), 0);
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        this.systemTemp.update(id, (String) null, Integer.valueOf(high), Integer.valueOf(medium), Integer.valueOf(low), Integer.valueOf(info), (String) null, version, DataRule.getRuleWhere(session, "t_sys_policies"), uid);
    }

    public Map<String, Object> save(HttpSession session, Integer id, String name, String desct, Integer version) throws Exception {
        Map<String, Object> result;
        Integer count = this.systemTemp.getCountByName(name, id, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在");
        }
        new HashMap();
        if (id == null) {
            Integer uid = ((User) session.getAttribute("userInfo")).getId();
            String path = String.valueOf(System.nanoTime()) + ".txt";
            FileUtils.writeStringToFile(new File(Constant.SYSTEM_DIC, path), "", "UTF-8");
            result = new HashMap<>();
            result.put("name", name);
            result.put("desct", desct);
            result.put("uid", uid);
            result.put("path", path);
            result.put("version", 0);
            this.systemTemp.insert(result);
        } else {
            this.systemTemp.saveUpdate(id, name, desct, version, DataRule.getRuleWhere(session, "t_sys_policies"));
            result = this.systemTemp.getTemplateById(id);
        }
        return result;
    }

    public Integer getCheckedPoliCount(Integer id, String family, String name, Integer lv, String cve, String cnnvd, String cncve, String cnvd) throws Exception {
        return this.systemTemp.getCheckedPoliCount(id, family, name, lv, cve, cnnvd, cncve, cnvd);
    }

    public List<String> getMidPidByTmpid(Integer id) throws Exception {
        return this.systemTemp.getMidPidByTmpid(id);
    }

    public List<String> getOidByTmpid(Integer tmpid) throws Exception {
        return this.systemTemp.getOidByTmpid(tmpid);
    }

    public Map<String, Object> getTempByName(String name) throws Exception {
        return this.systemTemp.getTempByName(name);
    }
}
